nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Fiford

Struct Fiford 

#[repr(transparent)]
pub struct Fiford(pub u32);
FIFO read data.

Tuple Fields

0: u32

Implementations

Source

impl Fiford

pub const fn rxdata(&self) -> u32

Received data from the FIFO. The number of bits used depends on configuration details.

pub const fn set_rxdata(&mut self, val: u32)

Received data from the FIFO. The number of bits used depends on configuration details.