nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Fiford48h

Struct Fiford48h 

#[repr(transparent)]
pub struct Fiford48h(pub u32);
FIFO read data for upper data bits. May only be used if the I2S is configured for 2x 24-bit data and not using DMA.

Tuple Fields

0: u32

Implementations

Source

impl Fiford48h

pub const fn rxdata(&self) -> u32

Received data from the FIFO. Whether this register is used and the number of bits used depends on configuration details.

pub const fn set_rxdata(&mut self, val: u32)

Received data from the FIFO. Whether this register is used and the number of bits used depends on configuration details.