#[repr(transparent)]pub struct Fiford48h(pub u32);Expand description
FIFO read data for upper data bits. May only be used if the I2S is configured for 2x 24-bit data and not using DMA.
Tuple Fields
0: u32Implementations
Sourceimpl Fiford48h
impl Fiford48h
Sourcepub const fn rxdata(&self) -> u32
pub const fn rxdata(&self) -> u32
Received data from the FIFO. Whether this register is used and the number of bits used depends on configuration details.
Sourcepub const fn set_rxdata(&mut self, val: u32)
pub const fn set_rxdata(&mut self, val: u32)
Received data from the FIFO. Whether this register is used and the number of bits used depends on configuration details.